local L = LibStub("AceLocale-3.0"):GetLocale("Luggage")

Luggage:RegisterFilter("Rarity", {
   name = L["Rarity"],
   tooltipText = L["Filter items by rarity"],
   values = {
      {
         name = L["Poor"],
         tooltipTitle = L["Poor"],
         tooltipText = L["Poor (grey) items"],
      },
      {
         name = L["Common"],
         tooltipTitle = L["Common"],
         tooltipText = L["Common (white) items"],
      },
      {
         name = L["Uncommon"],
         tooltipTitle = L["Uncommon"],
         tooltipText = L["Uncommon (gree) items"],
      },
      {
         name = L["Rare"],
         tooltipTitle = L["Rare"],
         tooltipText = L["Rare (blue) items"],
      },
      {
         name = L["Epic"],
         tooltipTitle = L["Epic"],
         tooltipText = L["Epic (purple) items"],
      },
   },
   func = function(bag, itemTable, rarity)
      return itemTable.rarity == rarity - 1
   end,
})

Luggage:RegisterFilter("Location", {
   name = L["Location"],
   tooltipText = L["Filter items depending on where they are in your inventory"],
   values = {
      {
         name = L["Bank"],
         tooltipTitle = L["Bank"],
         tooltipText = L["All items in your bank"],
      },
      {
         name = L["Main Bags"],
         tooltipTitle = L["Main Bags"],
         tooltipText = L["All items in your main bags"],
      },
   },
   func = function(bag, itemTable, position)
      local bagID = itemTable.bagID
      if position == 1 then
         return type(bagID) == "string" and bagID == "bank" or (bagID > NUM_BAG_SLOTS and bagID <= NUM_BAG_SLOTS + NUM_BANKBAGSLOTS)
      elseif position == 2 then
         return bagID ~= "bank" and bagID <= NUM_BAG_SLOTS
      end
   end,
})

local bagsCheckingUnsorted = {}
Luggage:RegisterFilter("Unsorted", {
   name = L["Unsorted"],
   tooltipText = L["Filter items that aren't contained by other bags. Beware! The almighty Unsorted filter doesn't like being set to red. If you do it anyways, the Unsorted filter will not strike you down, as he is a benevolent filter, but he will cause your virtual bag to appear always empty."],
   func = function(currentBag, itemTable)
      bagsCheckingUnsorted[currentBag] = true
      for i, bag in ipairs(Luggage.bags) do
         if     not bagsCheckingUnsorted[bag]
            and     bag:ContainsItem(itemTable, {Unsorted = true}) then
            bagsCheckingUnsorted[currentBag] = nil
            return false
         end
      end
      bagsCheckingUnsorted[currentBag] = nil
      return true
   end,
})

Luggage:RegisterFilter("Quest_Item", {
   name = L["Quest Items"],
   tooltipText = L["Filter quest items. Note: This only includes items marked as \"Quest Item\" in their tooltips."],
   func = function(bag, itemTable)
      return itemTable.binding == ITEM_BIND_QUEST
   end,
})

Luggage:RegisterFilter("Binding", {
   name = L["Binding"],
   tooltipText = L["Filter items by their binding status."],
   values = {
      BoE = {
         name = L["BoE"],
         tooltipText = string.format(L["Filters all items that have \"%s\" in their tooltip."], ITEM_BIND_ON_EQUIP),
      },
      BoP = {
         name = L["BoP"],
         tooltipText = string.format(L["Filters all items that have \"%s\" in their tooltip."], ITEM_BIND_ON_PICKUP),
      },
      BoU = {
         name = L["BoU"],
         tooltipText = string.format(L["Filters all items that have \"%s\" in their tooltip."], ITEM_BIND_ON_USE),
      },
      Soulbound = {
         name = ITEM_SOULBOUND,
         tooltipText = string.format(L["Filters all items that have \"%s\" in their tooltip."], ITEM_SOULBOUND),
      },
   },
   func = function(bag, itemTable, binding)
      if binding == "BoE" then
         return itemTable.binding == ITEM_BIND_ON_EQUIP
      elseif binding == "BoP" then
         return itemTable.binding == ITEM_BIND_ON_PICKUP
      elseif binding == "BoU" then
         return itemTable.binding == ITEM_BIND_ON_USE
      elseif binding == "Soulbound" then
         return itemTable.binding == ITEM_SOULBOUND
      end
   end,
})

Luggage:RegisterFilter("Type", {
   name = L["Type"],
   tooltipText = L["Filter by the type of the item."],
   values = {
      Armor = {
         name = L["Armor"],
         tooltipText = L["Armor of all types"],
      },
      Gem = {
         name = L["Gem"],
         tooltipText = L["Gems of all colors"],
      },
      Projectile = {
         name = L["Ammunition"],
         tooltipText = L["Things that hurt from afar"],
      },
      Weapon = {
         name = L["Weapon"],
         tooltipText = L["Things that hurt when close"],
      },
   },
   func = function(bag, item, value)
      return item.type == value
   end,
})

Luggage:RegisterFilter("Consumable", {
   name = L["Consumable"],
   tooltipText = L["Filter items you can eat, drink or otherwise consume. Or make others consume. Possibly with force."],
   values = {
      ["Food & Drink"] = {
         name = L["Food & Drink"],
         tooltipText = L["Yummy."],
      },
      Potion = {
         name = L["Potion"],
         tooltipText = L["Potions of all kinds. (Those with 2 minute cooldown)"],
      },
      Flasks_Elixirs = {
         name = L["Flasks & Elixirs"],
         tooltipText = L["Colorful drinks with long term effects. Keep away from small children."],
      },
      Bandage = {
         name = L["Bandage"],
         tooltipText = L["For when you cut yourself"],
      },
      ["Item Enhancement"] = {
         name = L["Item Enhancement"],
         tooltipText = L["Sharpening stones, poisons, etc."],
      },
      Scroll = {
         name = L["Scroll"],
         tooltipText = L["For when you forget your text"],
      },
      Other = {
         name = L["Other"],
         tooltipText = L["The others are not coming. They are right in your bag."],
      },
   },
   func = function(bag, item, subType)
      if item.type ~= "Consumable" then
         return false
      end
      if subType == "Flasks_Elixirs" then
         return item.subType == "Flask" or item.subType == "Elixir"
      else
         return item.subType == subType
      end
   end,
})

Luggage:RegisterFilter("Tradeskill", {
   name = L["Tradeskill"],
   tooltipText = L["Things for your craft"],
   values = {
--~       Elemental = {
--~          name = L["Elemental"],
--~          tooltipText = ???
--~       },
      Cloth = {
         name = L["Cloth"],
         tooltipText = L["Rags and fine fabrics"],
      },
      Leather = {
         name = L["Leather"],
         tooltipText = L["Dead animal's exterior"],
      },
      ["Metal & Stone"] = {
         name = L["Metal & Stone"],
         tooltipText = L["Ripped from the rocks"],
      },
      Meat = {
         name = L["Meat"],
         tooltipText = L["Dead animal's interior"],
      },
      Herb = {
         name = L["Herb"],
         tooltipText = L["Ripped from the earth"],
      },
      Enchanting = {
         name = L["Enchanting"],
         tooltipText = L["Making things glow"],
      },
      Jewelcrafting = {
         name = L["Jewelcrafting"],
         tooltipText = L["Making shiny things shinier"],
      },
      Parts = {
         name = L["Parts"],
         tooltipText = L["Why is that screw left over?"],
      },
      Devices = {
         name = L["Device"],
         tooltipText = L["I wonder what that big red button does..."],
      },
      Explosives = {
         name = L["Explosives"],
         tooltipText = L["Special effects"],
      },
--~       Materials = {
--~          name = L["Materials"],
--~          tooltipText = L["Rags and fine fabrics"]
--~       },
--~       Other = {
--~          name = L["Cloth"],
--~          tooltipText = L["Rags and fine fabrics"]
--~       },
   },
   func = function(bag, item, subType)
      if item.type ~= "Trade Goods" then
         return
      end
      return item.subType == subType
   end,
})